- `PEP 492 - Coroutines with async and await syntax <https://peps.python.org/pep-0492/>`_
- `contextlib.asynccontextmanager <https://docs.python.org/3/library/contextlib.html#contextlib.asynccontextmanager>`_
